@@ -1,4 +1,4 @@
-# Copyright (c) 2013, Menno Smits
+# Copyright (c) 2014, Menno Smits
 # Released subject to the New BSD License
 # Please see http://en.wikipedia.org/wiki/BSD_licenses
 
@@ -25,5 +25,5 @@ print("Messages:")
 response = server.fetch(messages, ['FLAGS', 'RFC822.SIZE'])
 for msgid, data in response.iteritems():
     print('   ID %d: %d bytes, flags=%s' % (msgid,
-                                            data['RFC822.SIZE'],
-                                            data['FLAGS']))
+                                            data[b'RFC822.SIZE'],
+                                            data[b'FLAGS']))
